#[non_exhaustive]pub enum ApplicationType {
Unknown,
MainWindow,
OtherWindow,
Service,
Explorer,
Console,
Critical,
Unrecognized(i32),
}Expand description
The kind of an affected application, corresponding to RM_APP_TYPE.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown
Windows explicitly reported RmUnknownApp.
MainWindow
An application with a top-level window.
OtherWindow
An application without a top-level window.
Service
A Windows service.
Explorer
Windows Explorer.
Console
A console application.
Critical
Windows reported RmCritical.
This can describe applications that cannot be shut down without a reboot; it is not merely a process criticality flag.
Unrecognized(i32)
A value introduced by a newer Windows version.
Implementations