ApplicationRestartOptions

Struct ApplicationRestartOptions 

pub struct ApplicationRestartOptions { /* private fields */ }
Command-line arguments and positive restart policies for this application.

The executable name must not be included. The default permits restart after every supported reason.

Implementations

Source

impl ApplicationRestartOptions

pub fn new(arguments: impl Into<OsString>) -> Self

Creates options with the supplied restart arguments and all reasons enabled.

pub fn with_arguments(self, arguments: impl Into<OsString>) -> Self

Replaces the restart arguments.

pub const fn with_restart_on_crash(self, enabled: bool) -> Self

Chooses whether restart is allowed after an unhandled crash.

pub const fn with_restart_on_hang(self, enabled: bool) -> Self

Chooses whether restart is allowed after an application hang.

pub const fn with_restart_on_update(self, enabled: bool) -> Self

Chooses whether restart is allowed after an update.

pub const fn with_restart_on_reboot(self, enabled: bool) -> Self

Chooses whether restart is allowed after a system reboot.

pub const fn restart_on_crash(&self) -> bool

Returns whether crash restart is allowed.

pub const fn restart_on_hang(&self) -> bool

Returns whether hang restart is allowed.

pub const fn restart_on_update(&self) -> bool

Returns whether update restart is allowed.

pub const fn restart_on_reboot(&self) -> bool

Returns whether reboot restart is allowed.