pub struct ApplicationRestartRegistration { /* private fields */ }Expand description
An exclusive crate-managed lease for the current process registration.
Implementations
Sourceimpl ApplicationRestartRegistration
impl ApplicationRestartRegistration
Sourcepub fn register(options: ApplicationRestartOptions) -> Result<Self>
pub fn register(options: ApplicationRestartOptions) -> Result<Self>
Registers this process for application restart.
Sourcepub fn update(&mut self, options: ApplicationRestartOptions) -> Result<()>
pub fn update(&mut self, options: ApplicationRestartOptions) -> Result<()>
Updates the command line and policies without releasing the lease.
Sourcepub fn unregister(self) -> Result<()>
pub fn unregister(self) -> Result<()>
Explicitly unregisters this process.
On failure the value remains armed and its destructor makes one best-effort retry.