pub struct ShutdownOptions { /* private fields */ }Expand description
Options accepted by crate::RestartSession::shutdown_with_options.
Implementations
Sourceimpl ShutdownOptions
impl ShutdownOptions
Sourcepub const fn with_force_if_hung(self, enabled: bool) -> Self
pub const fn with_force_if_hung(self, enabled: bool) -> Self
Chooses whether unresponsive applications may be force-terminated.
Enabling this can cause data loss in affected applications.
Sourcepub const fn with_require_restart_registration(self, enabled: bool) -> Self
pub const fn with_require_restart_registration(self, enabled: bool) -> Self
Requires every affected application to have registered for restart.
Sourcepub const fn force_if_hung(self) -> bool
pub const fn force_if_hung(self) -> bool
Returns whether forced termination is enabled.
Sourcepub const fn require_restart_registration(self) -> bool
pub const fn require_restart_registration(self) -> bool
Returns whether every affected application must be restartable.