pub struct ApplicationRestartOptions { /* private fields */ }Expand description
Command-line arguments and positive restart policies for this application.
The executable name must not be included. The default permits restart after every supported reason.
Implementations
Sourceimpl ApplicationRestartOptions
impl ApplicationRestartOptions
Sourcepub fn new(arguments: impl Into<OsString>) -> Self
pub fn new(arguments: impl Into<OsString>) -> Self
Creates options with the supplied restart arguments and all reasons enabled.
Sourcepub fn with_arguments(self, arguments: impl Into<OsString>) -> Self
pub fn with_arguments(self, arguments: impl Into<OsString>) -> Self
Replaces the restart arguments.
Sourcepub const fn with_restart_on_crash(self, enabled: bool) -> Self
pub const fn with_restart_on_crash(self, enabled: bool) -> Self
Chooses whether restart is allowed after an unhandled crash.
Sourcepub const fn with_restart_on_hang(self, enabled: bool) -> Self
pub const fn with_restart_on_hang(self, enabled: bool) -> Self
Chooses whether restart is allowed after an application hang.
Sourcepub const fn with_restart_on_update(self, enabled: bool) -> Self
pub const fn with_restart_on_update(self, enabled: bool) -> Self
Chooses whether restart is allowed after an update.
Sourcepub const fn with_restart_on_reboot(self, enabled: bool) -> Self
pub const fn with_restart_on_reboot(self, enabled: bool) -> Self
Chooses whether restart is allowed after a system reboot.
Sourcepub const fn restart_on_crash(&self) -> bool
pub const fn restart_on_crash(&self) -> bool
Returns whether crash restart is allowed.
Sourcepub const fn restart_on_hang(&self) -> bool
pub const fn restart_on_hang(&self) -> bool
Returns whether hang restart is allowed.
Sourcepub const fn restart_on_update(&self) -> bool
pub const fn restart_on_update(&self) -> bool
Returns whether update restart is allowed.
Sourcepub const fn restart_on_reboot(&self) -> bool
pub const fn restart_on_reboot(&self) -> bool
Returns whether reboot restart is allowed.