pub struct RecoveryCompletion { /* private fields */ }Expand description
Completed recovery state with retained results and post-operation reporting.
This typestate is Send.
Implementations
Sourceimpl RecoveryCompletion
impl RecoveryCompletion
Sourcepub const fn outcome(&self) -> &RecoveryOutcome
pub const fn outcome(&self) -> &RecoveryOutcome
Returns both retained operation outcomes.
Sourcepub fn affected_applications(&mut self) -> Result<AffectedApplications>
pub fn affected_applications(&mut self) -> Result<AffectedApplications>
Takes a post-operation affected-application snapshot.
Sourcepub fn end(self) -> Result<RecoveryOutcome>
pub fn end(self) -> Result<RecoveryOutcome>
Ends the session and returns both retained operation outcomes.
If ending fails, destruction retries the native end once.